to_pascal_case

Function to_pascal_case 

pub fn to_pascal_case(snake: &str) -> String
Convert a snake_case identifier to PascalCase. Used to derive the service struct name from its file name (email_senderEmailSender).

Assumes the input has already been validated as a snake_case identifier (no leading digits, no hyphens, etc).